@@ -170,36 +170,65 @@ TCGAquery_MatchedCoupledSampleTypes <- function(barcode,typesample){
 #' @export
 #' @importFrom data.table rbindlist as.data.table
 #' @importFrom jsonlite fromJSON
+#' @importFrom dplyr summarise
 #' @examples
-#' clinical <- GDCquery_clinic(project = "TCGA-ACC", type = "clinical", save.csv = TRUE)
-#' clinical <- GDCquery_clinic(project = "TCGA-ACC", type = "biospecimen", save.csv = TRUE)
-#' clinical.cptac2 <- GDCquery_clinic(project = "CPTAC-2", type = "clinical")
-#' clinical.TARGET_ALL_P1 <- GDCquery_clinic(project =  "TARGET-ALL-P1", type = "clinical")
-#' clinicaln.fm_ad <- GDCquery_clinic(project = "FM-AD", type = "clinical")
+#' clinical <- GDCquery_clinic(
+#'    project = "TCGA-ACC",
+#'    type = "clinical",
+#'    save.csv = FALSE
+#'  )
+#' clinical <- GDCquery_clinic(
+#'    project = "TCGA-ACC",
+#'    type = "biospecimen",
+#'    save.csv = FALSE
+#' )
 #' \dontrun{
-#' clinical.cptac_3 <- GDCquery_clinic(project = "CPTAC-3", type = "clinical")
-#' clinical.cptac_2 <- GDCquery_clinic(project = "CPTAC-2", type = "clinical")
-#' clinical.HCMI_CMDC <- GDCquery_clinic(project = "HCMI-CMDC", type = "clinical")
-#' clinical.CGCI-HTMCP-CC <- GDCquery_clinic(project = "CGCI-HTMCP-CC", type = "clinical")
-#' clinical <- GDCquery_clinic(project = "NCICCR-DLBCL", type = "clinical")
-#' clinical <- GDCquery_clinic(project = "ORGANOID-PANCREATIC", type = "clinical")
+#' clinical_cptac_3 <- GDCquery_clinic(
+#'    project = "CPTAC-3",
+#'    type = "clinical"
+#' )
+#' clinical_cptac_2 <- GDCquery_clinic(
+#'    project = "CPTAC-2",
+#'    type = "clinical"
+#' )
+#' clinical_HCMI_CMDC <- GDCquery_clinic(
+#'    project = "HCMI-CMDC",
+#'    type = "clinical"
+#' )
+#' clinical_GCI_HTMCP_CC <- GDCquery_clinic(
+#'    project = "CGCI-HTMCP-CC",
+#'    type = "clinical"
+#' )
+#' clinical <- GDCquery_clinic(
+#'    project = "NCICCR-DLBCL",
+#'    type = "clinical"
+#' )
+#' clinical <- GDCquery_clinic(
+#'    project = "ORGANOID-PANCREATIC",
+#'    type = "clinical"
+#' )
 #' }
 #' @return A data frame with the clinical information
 #' @author Tiago Chedraoui Silva
 GDCquery_clinic <- function(
-    project,
-    type = "clinical",
-    save.csv = FALSE
+        project,
+        type = "clinical",
+        save.csv = FALSE
 ){
     checkProjectInput(project)
 
-    if(length(project) > 1) stop("Please, project should be only one valid project")
+    if (length(project) > 1) {
+        stop("Please, project should be only one valid project")
+    }
+
+    if (!grepl("clinical|Biospecimen",type,ignore.case = TRUE)) {
+        stop("Type must be clinical or Biospecimen")
+    }
 
-    if(!grepl("clinical|Biospecimen",type,ignore.case = TRUE)) stop("Type must be clinical or Biospecimen")
     baseURL <- "https://api.gdc.cancer.gov/cases/?"
     options.pretty <- "pretty=true"
 
-    if(grepl("clinical",type,ignore.case = TRUE)) {
+    if (grepl("clinical",type,ignore.case = TRUE)) {
         options.expand <- "expand=diagnoses,diagnoses.treatments,annotations,family_histories,demographic,exposures"
         option.size <- paste0("size=",getNbCases(project,"Clinical"))
         files.data_category <- "Clinical"
@@ -209,7 +238,7 @@ GDCquery_clinic <- function(
         files.data_category <- "Biospecimen"
     }
 
-    if(grepl("TCGA",project)){
+    if (grepl("TCGA",project)){
         options.filter <- paste0(
             "filters=",
             URLencode('{"op":"and","content":[{"op":"in","content":{"field":"cases.project.project_id","value":["'),
@@ -238,27 +267,32 @@ GDCquery_clinic <- function(
     #message(paste0(baseURL,paste(options.pretty,options.expand, option.size, options.filter, sep = "&")))
     results <- json$data$hits
 
-    if(grepl("clinical",type,ignore.case = TRUE)) {
-        if(grepl("TCGA",project)) {
+    if (grepl("clinical",type,ignore.case = TRUE)) {
+        if (grepl("TCGA",project)) {
             df <- data.frame("submitter_id" = results$submitter_id)
-            if("diagnoses" %in% colnames(results)){
+            if ("diagnoses" %in% colnames(results)){
                 diagnoses <- rbindlist(lapply(results$diagnoses, function(x) if(is.null(x)) data.frame(NA) else x),fill = T)
                 diagnoses$submitter_id <- gsub("_diagnosis","", df$submitter_id)
                 df <- merge(df,diagnoses, by="submitter_id", all = TRUE, sort = FALSE)
             }
-            if("exposures" %in% colnames(results)){
+            if ("exposures" %in% colnames(results)){
                 exposures <- rbindlist(results$exposures, fill = TRUE)
                 exposures <- exposures[,-c("updated_datetime","state","created_datetime")]
                 exposures$submitter_id <- gsub("_exposure","", exposures$submitter_id)
                 df <- merge(df,exposures, by="submitter_id", all = TRUE, sort = FALSE)
             }
-            if("demographic" %in% colnames(results)){
+            if ("demographic" %in% colnames(results)){
                 results$demographic$submitter_id <- gsub("_demographic","", results$demographic$submitter_id)
                 demographic <- results$demographic[!is.na(results$demographic$submitter_id),]
-                df <- merge(df,
-                            as.data.table(demographic)[,-c("updated_datetime","state","created_datetime")],
-                            by = "submitter_id", all = TRUE, sort = FALSE)
+                df <- merge(
+                    df,
+                    as.data.table(demographic)[,-c("updated_datetime","state","created_datetime")],
+                    by = "submitter_id",
+                    all = TRUE,
+                    sort = FALSE
+                )
             }
+
             if("treatments" %in% colnames(df)){
                 treatments <- rbindlist(df$treatments,fill = TRUE)
                 df$treatments <- NULL
@@ -278,9 +312,11 @@ GDCquery_clinic <- function(
                 df <- merge(df, as.data.table(treatments.pharmaceutical), by = "submitter_id",  all = TRUE, sort = FALSE)
                 df <- merge(df, as.data.table(treatments.radiation), by = "submitter_id",  all = TRUE, sort = FALSE)
             }
+
             df$bcr_patient_barcode <- df$submitter_id
             df$project <- project
             df <- df %>% dplyr::relocate(project)
+
         } else {
 
             # Although for TCGA and TARGET IDs from diagnosis, treatments, exposures etc are the same
@@ -309,13 +345,19 @@ GDCquery_clinic <- function(
                             } else {
                                 # HTMCP-03-06-02061 has two diagnosis
                                 x$submitter_id <- gsub("_diagnosis.*","",x$submitter_id)
+                                # If there are two rows for the same submitter_id
+                                # we will collapse them into one single row
+                                # concatanating all columns using ;
                                 aux <- x %>% dplyr::group_by(submitter_id) %>%
-                                    dplyr::summarise_each(funs(paste(unique(.), collapse = ";")))
+                                    dplyr::summarise(
+                                        across(everything(),~ paste(unique(.), collapse = ";"))
+                                    )
+
                                 aux$treatments <- list(dplyr::bind_rows(x$treatments))
                                 aux
                             }
-                            }
-                    ),fill = T
+                        }
+                    ), fill = TRUE
                 )
                 #df$submitter_id <- gsub("^d|_diagnosis|diag-|-DX|-DIAG|-diagnosis","", df$submitter_id)
                 # ^d ORGANOID-PANCREATIC
@@ -368,12 +410,12 @@ GDCquery_clinic <- function(
         df <- rbindlist(results$samples,fill = TRUE)
     }
 
-    if(save.csv){
+    if (save.csv) {
         if(grepl("biospecimen",type))  {
             df$portions <- NULL
             message("Portion column is a list, it will be removed. Please check object with save.csv argument as FALSE")
         }
-        if(grepl("clinical",type))  {
+        if (grepl("clinical",type))  {
             df$treatments <- NULL
             message("Treatments column is a list, it will be removed. Please check object with save.csv argument as FALSE")
         }
@@ -399,19 +441,22 @@ GDCquery_clinic <- function(
 #' @return A data frame with the parsed values from the XML
 #' @export
 #' @examples
-#' query <- GDCquery(project = "TCGA-COAD",
-#'                   data.category = "Clinical",
-#'                   file.type = "xml",
-#'                   barcode = c("TCGA-RU-A8FL","TCGA-AA-3972"))
+#' query <- GDCquery(
+#'   project = "TCGA-COAD",
+#'   data.category = "Clinical",
+#'   data.format = "bcr xml",
+#'   barcode = c("TCGA-RU-A8FL","TCGA-AA-3972")
+#' )
 #' GDCdownload(query)
 #' clinical <- GDCprepare_clinic(query,"patient")
 #' clinical.drug <- GDCprepare_clinic(query,"drug")
 #' clinical.radiation <- GDCprepare_clinic(query,"radiation")
 #' clinical.admin <- GDCprepare_clinic(query,"admin")
+#' \dontrun{
 #' query <- GDCquery(
 #'    project = "TCGA-COAD",
 #'    data.category = "Biospecimen",
-#'    file.type = "xml",
+#'    data.format = "bcr xml",
 #'    data.type = "Biospecimen Supplement",
 #'    barcode = c("TCGA-RU-A8FL","TCGA-AA-3972")
 #' )
@@ -420,10 +465,11 @@ GDCquery_clinic <- function(
 #' clinical.drug <- GDCprepare_clinic(query,"sample")
 #' clinical.radiation <- GDCprepare_clinic(query,"portion")
 #' clinical.admin <- GDCprepare_clinic(query,"slide")
+#' }
 GDCprepare_clinic <- function(
-    query,
-    clinical.info,
-    directory = "GDCdata"
+        query,
+        clinical.info,
+        directory = "GDCdata"
 ){
 
     if (unique(query$results[[1]]$data_category) == "Clinical") {
@@ -461,9 +507,9 @@ GDCprepare_clinic <- function(
     }
 
     # Get all the clincal xml files
-    source <- ifelse(query$legacy,"legacy","harmonized")
+
     files <- file.path(
-        query$results[[1]]$project, source,
+        query$results[[1]]$project,
         gsub(" ","_",query$results[[1]]$data_category),
         gsub(" ","_",query$results[[1]]$data_type),
         gsub(" ","_",query$results[[1]]$file_id),
@@ -540,6 +586,30 @@ GDCprepare_clinic <- function(
             clin$primary_pathology <- NULL
         }
 
+        # Update clinical data with follow-ups: days_to_last_followup and vital_status
+        message("Updating days_to_last_followup and vital_status from follow_up information using last entry")
+        followup <- parseFollowup(files,xpath,clinical.info)
+
+        if(nrow(followup) > 0){
+            followup_last <- followup %>%
+                dplyr::group_by(bcr_patient_barcode) %>%
+                dplyr::summarise(
+                    days_to_last_followup = ifelse(
+                        all(is.na(as.numeric(days_to_last_followup))),
+                        NA,
+                        max(as.numeric(days_to_last_followup),na.rm = TRUE)
+                    ),
+                    vital_status = vital_status[
+                        ifelse(
+                            any(followup$days_to_last_followup %in% ""),
+                            which(followup$days_to_last_followup %in% ""),
+                            which.max(days_to_last_followup)
+                        )
+                    ]
+                )
+            clin$days_to_last_followup <- followup_last$days_to_last_followup[match(clin$bcr_patient_barcode,followup_last$bcr_patient_barcode)]
+            clin$vital_status <- followup_last$vital_status[match(clin$bcr_patient_barcode,followup_last$bcr_patient_barcode)]
+        }
     }
 
     if (tolower(clinical.info) == "sample") {
@@ -564,17 +634,13 @@ GDCprepare_clinic <- function(
         message("No information found")
         return(NULL)
     }
+
     # Converting factor to numeric and double
-    out <- clin %>%
-        dplyr::mutate_all(
-            funs(
-                type.convert(as.character(.), as.is = TRUE, numerals = "warn.loss")
-            )
-        )
+    out <- clin |> type.convert(as.is = TRUE, numerals = "warn.loss")
 
     # Change columns back to factor
     for (i in colnames(out)[!grepl("has_",colnames(out))]) {
-        if (class(out[,i]) == "character" &  length(unique(out[,i])) < nrow(out)/2)
+        if (is(out[,i],"character") &  length(unique(out[,i])) < nrow(out)/2)
             out[,i] <-  as.factor(out[,i])
     }
     return(out)
