@@ -60,21 +60,20 @@ GDCprepare <- function(
     isServeOK()
     if(missing(query)) stop("Please set query parameter")
 
-    test.duplicated.cases <-
-        (
-            any(
-                duplicated(query$results[[1]]$cases)) & # any duplicated
-                !(query$data.type %in% c(
-                    "Clinical data",
-                    "Protein expression quantification",
-                    "Raw intensities",
-                    "Masked Intensities",
-                    "Clinical Supplement",
-                    "Masked Somatic Mutation",
-                    "Biospecimen Supplement"
-                )
-                )
-        )
+    test.duplicated.cases <- (
+        any(
+            duplicated(query$results[[1]]$cases)) & # any duplicated
+            !(query$data.type %in% c(
+                "Clinical data",
+                "Protein expression quantification",
+                "Raw intensities",
+                "Masked Intensities",
+                "Clinical Supplement",
+                "Masked Somatic Mutation",
+                "Biospecimen Supplement"
+            )
+            )
+    )
 
 
     if(test.duplicated.cases) {
@@ -90,10 +89,10 @@ GDCprepare <- function(
     if (!save & remove.files.prepared) {
         stop("To remove the files, please set save to TRUE. Otherwise, the data will be lost")
     }
-    # We save the files in project/source/data.category/data.type/file_id/file_name
-    source <- ifelse(query$legacy,"legacy","harmonized")
+
+    # We save the files in project/data.category/data.type/file_id/file_name
     files <- file.path(
-        query$results[[1]]$project, source,
+        query$results[[1]]$project,
         gsub(" ","_",query$results[[1]]$data_category),
         gsub(" ","_",query$results[[1]]$data_type),
         gsub(" ","_",query$results[[1]]$file_id),
@@ -105,14 +104,19 @@ GDCprepare <- function(
     # For IDAT prepare since we need to put all IDATs in the same folder the code below will not work
     # a second run
     if (!all(file.exists(files))) {
-        # We have to check we movedthe files
-        if (query$data.type == "Masked Intensities" | query$data.category == "Raw microarray data"){
+        # We have to check we moved the files
+        if (
+            unique(query$results[[1]]$data_type) == "Masked Intensities" |
+            unique(query$results[[1]]$data_category) == "Raw microarray data"
+        ){
+
             files.idat <- file.path(
-                query$results[[1]]$project, source,
+                query$results[[1]]$project,
                 gsub(" ","_",query$results[[1]]$data_category),
                 gsub(" ","_",query$results[[1]]$data_type),
                 gsub(" ","_",query$results[[1]]$file_name)
             )
+
             files.idat <- file.path(directory, files.idat)
             if (!all(file.exists(files) | file.exists(files.idat))) {
                 stop(
@@ -165,17 +169,22 @@ GDCprepare <- function(
         if (unique(query$results[[1]]$data_type) == "Gene Level Copy Number Scores") {
             data <- readGISTIC(files, query$results[[1]]$cases)
         } else if (unique(query$results[[1]]$data_type) == "Gene Level Copy Number") {
-            data <- readGeneLevelCopyNumber(files, query$results[[1]]$cases,summarizedExperiment = summarizedExperiment)
+            data <- read_gene_level_copy_number(
+                files = files,
+                cases = query$results[[1]]$sample.submitter_id,
+                summarizedExperiment = summarizedExperiment
+            )
         } else {
-            data <- readCopyNumberVariation(files, query$results[[1]]$cases)
+            data <- read_copy_number_variation(
+                files = files, cases = query$results[[1]]$cases
+            )
         }
     }  else if (grepl("Methylation Beta Value",unique(query$results[[1]]$data_type), ignore.case = TRUE)) {
         data <- readDNAmethylation(
             files = files,
             cases = cases,
             summarizedExperiment = summarizedExperiment,
-            platform =  unique(query$results[[1]]$platform),
-            legacy = query$legacy
+            platform =  unique(query$results[[1]]$platform)
         )
     }  else if (grepl("Raw intensities|Masked Intensities",query$data.type, ignore.case = TRUE)) {
         # preparing IDAT files
@@ -183,45 +192,45 @@ GDCprepare <- function(
             files = files,
             barcode = cases,
             summarizedExperiment = summarizedExperiment,
-            platform =  unique(query$results[[1]]$platform),
-            legacy = query$legacy
+            platform =  unique(query$results[[1]]$platform)
         )
-    }  else if (grepl("Proteome Profiling",query$data.category,ignore.case = TRUE)) {
+    } else if (grepl("Proteome Profiling",query$data.category,ignore.case = TRUE)) {
 
         data <- readProteomeProfiling(files, cases = cases)
 
-    }  else if (grepl("Protein expression",query$data.category,ignore.case = TRUE)) {
+    } else if (grepl("Protein expression",query$data.category,ignore.case = TRUE)) {
 
         data <- readProteinExpression(files, cases = cases)
-        if(summarizedExperiment) {
+
+        if (summarizedExperiment) {
             message("SummarizedExperiment not implemented, if you need samples metadata use the function TCGAbiolinks:::colDataPrepare")
         }
 
     }  else if (grepl("Simple Nucleotide Variation",query$data.category,ignore.case = TRUE)) {
 
-        if(grepl("Masked Somatic Mutation",query$results[[1]]$data_type[1],ignore.case = TRUE) | source == "legacy"){
+        if (grepl("Masked Somatic Mutation",query$results[[1]]$data_type[1],ignore.case = TRUE)){
             data <- readSimpleNucleotideVariationMaf(files)
         }
 
     }  else if (grepl("Clinical|Biospecimen", query$data.category, ignore.case = TRUE)){
-        data <- readClinical(files, query$data.type, cases = cases)
+        data <- read_clinical(files, query$data.type, cases = cases)
         summarizedExperiment <- FALSE
     } else if (grepl("Gene expression",query$data.category,ignore.case = TRUE)) {
         if (query$data.type == "Gene expression quantification")
-            data <- readGeneExpressionQuantification(
+            data <- read_gene_expression_quantification(
                 files = files,
                 cases = cases,
                 summarizedExperiment = summarizedExperiment,
-                genome = ifelse(query$legacy,"hg19","hg38"),
+                genome = "hg38",
                 experimental.strategy = unique(query$results[[1]]$experimental_strategy)
             )
 
         if (query$data.type == "miRNA gene quantification")
-            data <- readGeneExpressionQuantification(
+            data <- read_gene_expression_quantification(
                 files = files,
                 cases = cases,
                 summarizedExperiment = FALSE,
-                genome = ifelse(query$legacy,"hg19","hg38"),
+                genome = "hg38",
                 experimental.strategy = unique(query$results[[1]]$experimental_strategy)
             )
 
@@ -290,22 +299,22 @@ GDCprepare <- function(
         # save is true, due to the check in the beggining of the code
         if(remove.files.prepared){
             # removes files and empty directories
-            remove.files.recursively(files)
+            remove_files_recursively(files)
         }
     }
 
     return(data)
 }
 
-remove.files.recursively <- function(files){
+remove_files_recursively <- function(files){
     files2rm <- dirname(files)
     unlink(files2rm,recursive = TRUE)
     files2rm <- dirname(files2rm) # data category
-    if(length(list.files(files2rm)) == 0) remove.files.recursively(files2rm)
+    if(length(list.files(files2rm)) == 0) remove_files_recursively(files2rm)
 }
 
 
-readClinical <- function(files, data.type, cases){
+read_clinical <- function(files, data.type, cases){
     if(data.type == "Clinical data"){
         suppressMessages({
             ret <- plyr::alply(files,.margins = 1,readr::read_tsv, .progress = "text")
@@ -368,14 +377,17 @@ readSingleCellAnalysis <- function(
 }
 
 #' @importFrom tidyr separate
-readExonQuantification <- function (files, cases, summarizedExperiment = TRUE){
+readExonQuantification <- function (
+        files,
+        cases,
+        summarizedExperiment = TRUE
+){
     pb <- txtProgressBar(min = 0, max = length(files), style = 3)
     assay.list <- NULL
 
     for (i in seq_along(files)) {
         data <- fread(files[i], header = TRUE, sep = "\t", stringsAsFactors = FALSE)
 
-
         if(!missing(cases)) {
             assay.list <- gsub(" |\\(|\\)|\\/","_",colnames(data)[2:ncol(data)])
             # We will use this because there might be more than one col for each samples
@@ -387,12 +399,14 @@ readExonQuantification <- function (files, cases, summarizedExperiment = TRUE){
         } else {
             df <- merge(df, data, by=colnames(data)[1], all = TRUE)
         }
+
         setTxtProgressBar(pb, i)
     }
     setDF(df)
     rownames(df) <- df[,1]
     df <- df %>% separate(exon,into = c("seqnames","coordinates","strand"),sep = ":") %>%
         separate(coordinates,into = c("start","end"),sep = "-")
+
     if(summarizedExperiment) {
         suppressWarnings({
             assays <- lapply(assay.list, function (x) {
@@ -400,8 +414,10 @@ readExonQuantification <- function (files, cases, summarizedExperiment = TRUE){
             })
         })
         names(assays) <- assay.list
-        regex <- paste0("[:alnum:]{4}-[:alnum:]{2}-[:alnum:]{4}",
-                        "-[:alnum:]{3}-[:alnum:]{3}-[:alnum:]{4}-[:alnum:]{2}")
+        regex <- paste0(
+            "[:alnum:]{4}-[:alnum:]{2}-[:alnum:]{4}",
+            "-[:alnum:]{3}-[:alnum:]{3}-[:alnum:]{4}-[:alnum:]{2}"
+        )
         samples <- na.omit(unique(str_match(colnames(df),regex)[,1]))
         colData <-  colDataPrepare(samples)
         assays <- lapply(assays, function(x){
@@ -511,7 +527,7 @@ readSimpleNucleotideVariationMaf <- function(files){
     return(ret)
 }
 
-readGeneExpressionQuantification <- function(
+read_gene_expression_quantification <- function(
         files,
         cases,
         genome = "hg19",
@@ -560,7 +576,7 @@ readGeneExpressionQuantification <- function(
     df <- bind_cols(ret[[1]][,1],df)
 
     if (summarizedExperiment) {
-        df <- makeSEfromGeneExpressionQuantification(df, assay.list, genome = genome)
+        df <- make_se_from_gene_exoression_quantification(df, assay.list, genome = genome)
     } else {
         rownames(df) <- df$gene_id
         df$gene_id <- NULL
@@ -569,7 +585,7 @@ readGeneExpressionQuantification <- function(
 }
 
 
-makeSEfromGeneExpressionQuantification <- function(
+make_se_from_gene_exoression_quantification <- function(
         df,
         assay.list,
         genome = "hg19"
@@ -713,14 +729,13 @@ readIDATDNAmethylation <- function(
         files,
         barcode,
         summarizedExperiment,
-        platform,
-        legacy
+        platform
 ) {
 
     check_package("sesame")
 
     # Check if moved files would be moved outside of scope folder, if so, path doesn't change
-    moved.files <- sapply(files,USE.NAMES=FALSE,function(x){
+    moved.files <- sapply(files,USE.NAMES = FALSE,function(x){
         if (grepl("Raw_intensities|Masked_Intensities",dirname(dirname(x)))) {
             return(file.path(dirname(dirname(x)), basename(x)))
         }
@@ -753,7 +768,7 @@ readIDATDNAmethylation <- function(
 
         betas <- makeSEFromDNAMethylationMatrix(
             betas = betas,
-            genome = ifelse(legacy,"hg19","hg38"),
+            genome ="hg38",
             met.platform = platform
         )
         colData(betas) <- DataFrame(colDataPrepare(colnames(betas)))
@@ -774,8 +789,7 @@ readDNAmethylation <- function(
         files,
         cases,
         summarizedExperiment = TRUE,
-        platform,
-        legacy
+        platform
 ){
     if(length(platform) > 1){
 
@@ -847,7 +861,7 @@ readDNAmethylation <- function(
 
             df <- makeSEFromDNAMethylationMatrix(
                 betas = df,
-                genome = ifelse(legacy,"hg19","hg38"),
+                genome = "hg38",
                 met.platform = platform
             )
         }
@@ -922,6 +936,8 @@ colDataPrepareMMRF <- function(barcode){
 }
 
 colDataPrepareTARGET <- function(barcode){
+
+
     message("Adding description to TARGET samples")
     tissue.code <- c(
         '01',
@@ -948,6 +964,7 @@ colDataPrepareTARGET <- function(barcode){
         '50',
         '60',
         '61',
+        '85',
         '99'
     )
 
@@ -976,28 +993,49 @@ colDataPrepareTARGET <- function(barcode){
         "Cell line from patient tumor", # 50
         "Xenograft from patient not grown as intermediate on plastic tissue culture dish", # 60
         "Xenograft grown in mice from established cell lines", #61
+        "Next Generation Cancer Model", # 85
         "Granulocytes after a Ficoll separation"
     ) # 99
-    aux <- DataFrame(tissue.code = tissue.code,definition)
+    aux <- data.frame(tissue.code = tissue.code,definition)
 
+    # Exceptions: TARGET-AML
+    # "TARGET-20-PAYKXV-Sorted-CD34neg-Lymphoid-09A" 727f5e27-09e9-425f-9757-81da66c054bd
+    # "TARGET-20-PAWUEX-EOI2-14A"  11fb7cce-06ad-445b-b09f-9dc1050e4cd4
+    # "TARGET-20-PAUSTZ-EOI1-14A" 3ad6dfa7-734d-41b0-ad66-15f0cff630d0
+    # "TARGET-20-PAYHMK-Sorted-leukemic-09A" f5bd72ae-919f-481c-8203-f878ee1c651a
+    # "TARGET-20-D7-Myeloid-mock3-85" 88712125-67e5-4e47-a413-e55b522a641c
+    # Normal case: TARGET-20-PANLXK-09A-03R
     # in case multiple equal barcode
-    regex <- paste0("[:alnum:]{6}-[:alnum:]{2}-[:alnum:]{6}",
-                    "-[:alnum:]{3}-[:alnum:]{3}")
-    samples <- str_match(barcode,regex)[,1]
+    #regex <- paste0("[:alnum:]{6}-[:alnum:]{2}-[:alnum:]{6}",
+    #                "-[:alnum:]{3}-[:alnum:]{3}")
+    #samples <- str_match(barcode,regex)[,1]
 
-    samples.df <- barcode %>% as.data.frame %>%  tidyr::separate(".",1:5 %>% as.character)
-
-    ret <- DataFrame(
-        barcode = barcode,
-        tumor.code = samples.df[,2],
-        sample = paste0(samples.df[,1],"-",samples.df[,2],"-",samples.df[,3],"-",samples.df[,4]),
-        patient = paste0(samples.df[,1],"-",samples.df[,2],"-",samples.df[,3]),
-        case.unique.id = paste0(samples.df[,3]),
-        tissue.code = substr(samples.df[,4], 1, 2),
-        nucleic.acid.code = substr(samples.df[,5], 3, 3)
-    )
-
-    ret <- merge(ret,aux, by = "tissue.code", sort = FALSE)
+    # this breaks for the exceptions
+    if(!any(grepl(";",barcode))){
+        ret <- data.frame(
+            barcode = barcode,
+            tumor.code = stringr::str_extract(pattern = "TARGET-[[:alnum:]]{2}",barcode) %>% gsub(pattern = "TARGET-","",.),
+            sample = gsub(pattern = "-[[:alnum:]]{3}$","",barcode),
+            patient = gsub(pattern = "-[[:alnum:]]{2,3}-[[:alnum:]]{3}$","",barcode),
+            case.unique.id = gsub(pattern = "-[[:alnum:]]{2,3}-[[:alnum:]]{3}$","",barcode) %>%  gsub(pattern = "TARGET-[[:alnum:]]{2}-","",.),
+            tissue.code = barcode %>% stringr::str_extract("[[:alnum:]]{2,3}-[[:alnum:]]{3}$") %>% stringr::str_extract("[[:alnum:]]{2,3}") %>% stringr::str_sub(1,2),
+            nucleic.acid.code = barcode %>% stringr::str_extract("[[:alnum:]]{3}$")  %>% stringr::str_sub(3,3)
+        )
+    } else {
+        # mixed samples case
+        ret <- purrr::map_dfr(.x = barcode,.f = function(b){
+            data.frame(
+                barcode = b,
+                tumor.code = stringr::str_extract(pattern = "TARGET-[[:alnum:]]{2}",b) %>% gsub(pattern = "TARGET-","",.),
+                sample = b %>% stringr::str_split(";") %>% unlist %>% sapply(FUN = function(y) gsub(pattern = "-[[:alnum:]]{3}$","",y)) %>% paste0(collapse = ";"),
+                patient = b %>% stringr::str_split(";") %>% unlist %>% sapply(FUN = function(y)  gsub(pattern = "-[[:alnum:]]{2,3}-[[:alnum:]]{3}$","",y)) %>% paste0(collapse = ";"),
+                case.unique.id = b %>% stringr::str_split(";") %>% unlist %>% sapply(FUN = function(y)  gsub(pattern = "-[[:alnum:]]{2,3}-[[:alnum:]]{3}$","",y)  %>%  gsub(pattern = "TARGET-[[:alnum:]]{2}-","",.) %>% paste0(collapse = ";")),
+                tissue.code = b %>% stringr::str_extract("[[:alnum:]]{2,3}-[[:alnum:]]{3}$") %>% stringr::str_extract("[[:alnum:]]{2,3}") %>% stringr::str_sub(1,2),
+                nucleic.acid.code = b %>% stringr::str_extract("[[:alnum:]]{3}$")  %>% stringr::str_sub(3,3)
+            )
+        })
+    }
+    ret <-  ret %>% dplyr::left_join(aux, by = "tissue.code")
 
     tumor.code <- c('00','01','02','03','04','10','15','20','21','30','40',
                     '41','50','51','52','60','61','62','63','64','65','70','71','80','81')
@@ -1029,8 +1067,8 @@ colDataPrepareTARGET <- function(barcode){
         "Rhabdomyosarcoma", #80
         "Soft tissue sarcoma, non-rhabdomyosarcoma"
     ) # 81
-    aux <- DataFrame(tumor.code = tumor.code,tumor.definition)
-    ret <- merge(ret,aux, by = "tumor.code", sort = FALSE)
+    aux <- data.frame(tumor.code = tumor.code,tumor.definition)
+    ret <- ret %>% dplyr::left_join(aux, by = "tumor.code")
 
     nucleic.acid.code <- c('D','E','W','X','Y','R','S')
     nucleic.acid.description <-  c(
@@ -1042,9 +1080,8 @@ colDataPrepareTARGET <- function(barcode){
         "RNA, from the first isolation of a tissue",
         "RNA, from the first isolation of a tissue embedded in FFPE"
     )
-    aux <- DataFrame(nucleic.acid.code = nucleic.acid.code,nucleic.acid.description)
-    ret <- merge(ret,aux, by = "nucleic.acid.code", sort = FALSE)
-
+    aux <- data.frame(nucleic.acid.code = nucleic.acid.code,nucleic.acid.description)
+    ret <- ret %>% dplyr::left_join(aux, by = "nucleic.acid.code")
 
     ret <- ret[match(barcode,ret$barcode),]
     rownames(ret) <- gsub("\\.","-",make.names(ret$barcode,unique=TRUE))
@@ -1056,31 +1093,37 @@ colDataPrepareTCGA <- function(barcode){
     # For the moment this will work only for TCGA Data
     # We should search what TARGET data means
 
-    code <- c('01','02','03','04','05','06','07','08','09','10','11',
-              '12','13','14','20','40','50','60','61')
-    shortLetterCode <- c("TP","TR","TB","TRBM","TAP","TM","TAM","THOC",
-                         "TBM","NB","NT","NBC","NEBV","NBM","CELLC","TRB",
-                         "CELL","XP","XCL")
+    code <- c(
+        '01','02','03','04','05','06','07','08','09','10','11',
+        '12','13','14','20','40','50','60','61'
+    )
+    shortLetterCode <- c(
+        "TP","TR","TB","TRBM","TAP","TM","TAM","THOC",
+        "TBM","NB","NT","NBC","NEBV","NBM","CELLC","TRB",
+        "CELL","XP","XCL"
+    )
 
-    definition <- c("Primary solid Tumor", # 01
-                    "Recurrent Solid Tumor", # 02
-                    "Primary Blood Derived Cancer - Peripheral Blood", # 03
-                    "Recurrent Blood Derived Cancer - Bone Marrow", # 04
-                    "Additional - New Primary", # 05
-                    "Metastatic", # 06
-                    "Additional Metastatic", # 07
-                    "Human Tumor Original Cells", # 08
-                    "Primary Blood Derived Cancer - Bone Marrow", # 09
-                    "Blood Derived Normal", # 10
-                    "Solid Tissue Normal",  # 11
-                    "Buccal Cell Normal",   # 12
-                    "EBV Immortalized Normal", # 13
-                    "Bone Marrow Normal", # 14
-                    "Control Analyte", # 20
-                    "Recurrent Blood Derived Cancer - Peripheral Blood", # 40
-                    "Cell Lines", # 50
-                    "Primary Xenograft Tissue", # 60
-                    "Cell Line Derived Xenograft Tissue") # 61
+    definition <- c(
+        "Primary solid Tumor", # 01
+        "Recurrent Solid Tumor", # 02
+        "Primary Blood Derived Cancer - Peripheral Blood", # 03
+        "Recurrent Blood Derived Cancer - Bone Marrow", # 04
+        "Additional - New Primary", # 05
+        "Metastatic", # 06
+        "Additional Metastatic", # 07
+        "Human Tumor Original Cells", # 08
+        "Primary Blood Derived Cancer - Bone Marrow", # 09
+        "Blood Derived Normal", # 10
+        "Solid Tissue Normal",  # 11
+        "Buccal Cell Normal",   # 12
+        "EBV Immortalized Normal", # 13
+        "Bone Marrow Normal", # 14
+        "Control Analyte", # 20
+        "Recurrent Blood Derived Cancer - Peripheral Blood", # 40
+        "Cell Lines", # 50
+        "Primary Xenograft Tissue", # 60
+        "Cell Line Derived Xenograft Tissue"
+    ) # 61
     aux <- DataFrame(code = code,shortLetterCode,definition)
 
     # in case multiple equal barcode
@@ -1088,10 +1131,12 @@ colDataPrepareTCGA <- function(barcode){
                     "-[:alnum:]{3}-[:alnum:]{3}-[:alnum:]{4}-[:alnum:]{2}")
     samples <- str_match(barcode,regex)[,1]
 
-    ret <- DataFrame(barcode = barcode,
-                     patient = substr(barcode, 1, 12),
-                     sample = substr(barcode, 1, 16),
-                     code = substr(barcode, 14, 15))
+    ret <- DataFrame(
+        barcode = barcode,
+        patient = substr(barcode, 1, 12),
+        sample = substr(barcode, 1, 16),
+        code = substr(barcode, 14, 15)
+    )
     ret <- merge(ret,aux, by = "code", sort = FALSE)
     ret <- ret[match(barcode,ret$barcode),]
     rownames(ret) <- gsub("\\.","-",make.names(ret$barcode,unique=TRUE))
@@ -1123,10 +1168,10 @@ colDataPrepare <- function(barcode){
     # Check if this breaks the package
     if(any(grepl("C3N-|C3L-",barcode))) {
         ret <- data.frame(
-            sample =  sapply(barcode, function(x) stringr::str_split(x,";") %>% unlist()) %>%
-                unlist %>% unique,stringsAsFactors = FALSE
+            sample = map(barcode,.f = function(x) stringr::str_split(x,";") %>% unlist) %>% unlist()
         )
     }
+
     if(is.null(ret)) {
         ret <- data.frame(
             sample = barcode %>% unique,
@@ -1150,7 +1195,6 @@ colDataPrepare <- function(barcode){
     }
     ret$bcr_patient_barcode <- ret$sample %>% as.character()
     ret$sample_submitter_id <- ret$sample %>% as.character()
-
     if(!"project_id" %in% colnames(ret)) {
         if("disease_type" %in% colnames(ret)){
             aux <- getGDCprojects()[,c(5,7)]
@@ -1164,7 +1208,15 @@ colDataPrepare <- function(barcode){
     }
 
     # na.omit should not be here, exceptional case
-    if(is.null(ret)) return(data.frame(row.names = barcode, barcode,stringsAsFactors = FALSE))
+    if(is.null(ret)) {
+        return(
+            data.frame(
+                row.names = barcode,
+                barcode,
+                stringsAsFactors = FALSE
+            )
+        )
+    }
 
     # Add purity information from http://www.nature.com/articles/ncomms9971
     # purity  <- getPurityinfo()
@@ -1181,7 +1233,7 @@ colDataPrepare <- function(barcode){
         }
     )
     # the code above does not work, since the projects have different string lengths
-    if(all(ret$project_id == "TARGET-ALL-P3")) {
+    if(all(na.omit(ret$project_id) %in% c("TARGET-ALL-P3","TARGET-AML"))) {
         idx <- sapply(gsub("-[[:alnum:]]{3}$","",barcode), function(x) {
             grep(x,ret$bcr_patient_barcode)
         })
@@ -1190,15 +1242,15 @@ colDataPrepare <- function(barcode){
     if(any(ret$project_id == "CPTAC-3",na.rm = T)) {
 
         # only merge mixed samples
-        mixed.samples <- grep(";",barcode,value = T)
-        if(length(mixed.samples) > 0){
-            mixed.samples <- unique(unlist(str_split(mixed.samples,";")))
+        mixed_samples <- grep(";",barcode,value = T)
+        if(length(mixed_samples) > 0){
+            mixed_samples <- mixed_samples %>% str_split(";") %>% unlist %>% unique
 
-            ret.mixed.samples <- ret %>% dplyr::filter(sample_submitter_id %in% mixed.samples) %>%
-                dplyr::group_by(submitter_id,sample_type) %>%
+            ret_mixed_samples <- ret %>% dplyr::filter(sample_submitter_id %in% mixed_samples) %>%
+                dplyr::group_by(submitter_id) %>%
                 dplyr::summarise_all(~trimws(paste(unique(.), collapse = ';'))) %>%
                 as.data.frame()
-            ret <- rbind(ret.mixed.samples,ret)
+            ret <- rbind(ret_mixed_samples,ret)
         }
         idx <- match(barcode,ret$bcr_patient_barcode)
 
@@ -1209,7 +1261,7 @@ colDataPrepare <- function(barcode){
 
     }
 
-    if(any(ret$project_id == "CMI-MBC",na.rm = T)) {
+    if(any(ret$project_id %in% c("CMI-MBC","TARGET-NBL"),na.rm = T)) {
         idx <- match(barcode,ret$bcr_patient_barcode)
     }
 
@@ -1563,7 +1615,11 @@ readTranscriptomeProfiling <- function(
     return(df)
 }
 
-readGeneLevelCopyNumber <- function(files, cases, summarizedExperiment = FALSE){
+read_gene_level_copy_number <- function(
+        files,
+        cases,
+        summarizedExperiment = FALSE
+){
     message("Reading Gene Level Copy Number files")
     gistic.df <- NULL
     gistic.list <- plyr::alply(files,1,.fun = function(file) {
@@ -1590,13 +1646,13 @@ readGeneLevelCopyNumber <- function(files, cases, summarizedExperiment = FALSE){
     )
 
     if(summarizedExperiment) {
-        se <- makeSEfromGeneLevelCopyNumber(df, cases)
+        se <- make_se_from_gene_level_copy_number(df, cases)
         return(se)
     }
     return(df)
 }
 
-makeSEfromGeneLevelCopyNumber <- function(df, cases){
+make_se_from_gene_level_copy_number <- function(df, cases){
     message("Creating a SummarizedExperiment object")
     rowRanges <- GRanges(
         seqnames = df$chromosome,
@@ -1656,7 +1712,7 @@ readGISTIC <- function(files, cases){
 
 # Reads Copy Number Variation files to a data frame, basically it will rbind it
 #' @importFrom purrr map2_dfr
-readCopyNumberVariation <- function(files, cases){
+read_copy_number_variation <- function(files, cases){
     message("Reading copy number variation files")
 
     col_types <- ifelse(any(grepl('ascat2', files)),"ccnnnnn","ccnnnd")
@@ -1696,10 +1752,12 @@ getFFPE <- function(patient){
     options.pretty <- "pretty=true"
     options.expand <- "expand=samples"
     option.size <- paste0("size=",length(patient))
-    options.filter <- paste0("filters=",
-                             URLencode('{"op":"and","content":[{"op":"in","content":{"field":"cases.submitter_id","value":['),
-                             paste0('"',paste(patient,collapse = '","')),
-                             URLencode('"]}}]}'))
+    options.filter <- paste0(
+        "filters=",
+        URLencode('{"op":"and","content":[{"op":"in","content":{"field":"cases.submitter_id","value":['),
+        paste0('"',paste(patient,collapse = '","')),
+        URLencode('"]}}]}')
+    )
     url <- paste0(baseURL,paste(options.pretty,options.expand, option.size, options.filter, sep = "&"))
     json  <- tryCatch(
         getURL(url,fromJSON,timeout(600),simplifyDataFrame = TRUE),
@@ -1723,10 +1781,12 @@ getAliquot_ids <- function(barcode){
     option.size <- paste0("size=",length(barcode))
     #message(paste(barcode,collapse = '","'))
     #message(paste0('"',paste(barcode,collapse = '","')))
-    options.filter <- paste0("filters=",
-                             URLencode('{"op":"and","content":[{"op":"in","content":{"field":"cases.submitter_id","value":['),
-                             paste0('"',paste(barcode,collapse = '","')),
-                             URLencode('"]}}]}'))
+    options.filter <- paste0(
+        "filters=",
+        URLencode('{"op":"and","content":[{"op":"in","content":{"field":"cases.submitter_id","value":['),
+        paste0('"',paste(barcode,collapse = '","')),
+        URLencode('"]}}]}')
+    )
     #message(paste0(baseURL,paste(options.pretty,options.expand, option.size, options.filter, sep = "&")))
     url <- paste0(baseURL,paste(options.pretty,options.fields, option.size, options.filter, sep = "&"))
     json  <- tryCatch(
@@ -1848,7 +1908,10 @@ getBarcodeInfo <- function(barcode) {
         }
     }
     if(!is.null(results$exposures)) {
-        exposures <- rbindlist(lapply(results$exposures, function(x) if(is.null(x)) data.frame(NA) else x),fill = TRUE)
+        exposures <- rbindlist(
+            lapply(results$exposures, function(x) if(is.null(x)) data.frame(NA) else x),
+            fill = TRUE
+        )
         exposures[,c("updated_datetime","created_datetime","state")] <- NULL
         if(any(grepl("submitter_id", colnames(exposures)))) {
             exposures$submitter_id <- gsub("-exposure|_exposure.*|-EXP","", exposures$submitter_id)
@@ -1868,7 +1931,11 @@ getBarcodeInfo <- function(barcode) {
         demographic <- results$demographic
         demographic[,c("updated_datetime","created_datetime","state")] <- NULL
         if(any(grepl("submitter_id", colnames(demographic)))) {
-            demographic$submitter_id <- gsub("-demographic|_demographic.*|-DEMO|demo-","", results$demographic$submitter_id)
+            demographic$submitter_id <- gsub(
+                "-demographic|_demographic.*|-DEMO|demo-",
+                "",
+                results$demographic$submitter_id
+            )
         } else {
             demographic$submitter_id <- submitter_id
         }
@@ -1889,7 +1956,9 @@ getBarcodeInfo <- function(barcode) {
                     .fun = function(x){
                         demographic[x,] %>% # replicate diagnoses the number of samples
                             as.data.frame() %>%
-                            dplyr::slice(rep(dplyr::row_number(), sum(results$submitter_sample_ids[[x]] %in% barcode)))})
+                            dplyr::slice(
+                                rep(dplyr::row_number(), sum(results$submitter_sample_ids[[x]] %in% barcode)))
+                    })
             }
 
             df <- dplyr::bind_cols(df  %>% as.data.frame,demographic)
@@ -1906,9 +1975,11 @@ getBarcodeInfo <- function(barcode) {
         projects.info <-  cbind("submitter_id" = submitter_id, projects.info)
 
         suppressWarnings({
-            df <- left_join(df,
-                            projects.info,
-                            by = "submitter_id")
+            df <- left_join(
+                df,
+                projects.info,
+                by = "submitter_id"
+            )
         })
     } else {
 
@@ -1918,7 +1989,9 @@ getBarcodeInfo <- function(barcode) {
                 .fun = function(x){
                     projects.info[x,] %>% # replicate diagnoses the number of samples
                         as.data.frame() %>%
-                        dplyr::slice(rep(dplyr::row_number(), sum(results$submitter_sample_ids[[x]] %in% barcode)))})
+                        dplyr::slice(
+                            rep(dplyr::row_number(), sum(results$submitter_sample_ids[[x]] %in% barcode)))
+                })
         }
 
         df <- dplyr::bind_cols(df,projects.info)
