@@ -8,42 +8,6 @@ library(SummarizedExperiment)
 library(dplyr)
 library(DT)
 
-## ----results = 'hide', message=FALSE, warning=FALSE, eval = F-----------------
-#  query <- GDCquery(
-#      project = "TCGA-GBM",
-#      data.category = "Gene expression",
-#      data.type = "Gene expression quantification",
-#      platform = "Illumina HiSeq",
-#      file.type  = "normalized_results",
-#      experimental.strategy = "RNA-Seq",
-#      barcode = c("TCGA-14-0736-02A-01R-2005-01", "TCGA-06-0211-02A-02R-2005-01"),
-#      legacy = TRUE
-#  )
-#  GDCdownload(
-#      query = query,
-#      method = "api",
-#      files.per.chunk = 10
-#  )
-#  data <- GDCprepare(query = query)
-
-## ----message=FALSE, warning=FALSE, include=FALSE------------------------------
-data <- gbm.exp.legacy
-
-## ----message=FALSE, warning=FALSE---------------------------------------------
-# Gene expression aligned against hg19.
-datatable(
-    as.data.frame(colData(data)), 
-    options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
-    rownames = FALSE)
-# Only first 20 rows to make render faster
-datatable(
-    assay(data)[1:20,], 
-    options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
-    rownames = TRUE
-)
-
-rowRanges(data)
-
 ## ----results = 'hide', message=FALSE, warning=FALSE, eval=FALSE---------------
 #  # Gene expression aligned against hg38
 #  query <- GDCquery(
@@ -201,8 +165,7 @@ rowRanges(data)
 #      project = "TCGA-BRCA",
 #      data.category = "DNA Methylation",
 #      data.type = "Masked Intensities",
-#      platform = "Illumina Human Methylation 27",
-#      legacy = FALSE
+#      platform = "Illumina Human Methylation 27"
 #  )
 #  GDCdownload(query, files.per.chunk=10)
 #  betas <- GDCprepare(query)
@@ -211,10 +174,9 @@ rowRanges(data)
 #      project = "HCMI-CMDC",
 #      data.category = "DNA Methylation",
 #      data.type = "Masked Intensities",
-#      platform = "Illumina Methylation Epic",
-#      legacy = FALSE
+#      platform = "Illumina Methylation Epic"
 #  )
-#  GDCdownload(query, files.per.chunk=10)
+#  GDCdownload(query, files.per.chunk = 10)
 #  betas <- GDCprepare(query)
 #  
 #  
@@ -222,8 +184,7 @@ rowRanges(data)
 #      project = "CPTAC-3",
 #      data.category = "DNA Methylation",
 #      data.type = "Masked Intensities",
-#      platform = "Illumina Methylation Epic",
-#      legacy = FALSE
+#      platform = "Illumina Methylation Epic"
 #  )
 #  GDCdownload(query, files.per.chunk=10)
 #  betas <- GDCprepare(query)
@@ -232,10 +193,9 @@ rowRanges(data)
 #      project = "TCGA-BRCA",
 #      data.category = "DNA Methylation",
 #      data.type = "Masked Intensities",
-#      platform = "Illumina Methylation Epic",
-#      legacy = FALSE
+#      platform = "Illumina Methylation Epic"
 #  )
-#  GDCdownload(query, files.per.chunk=10)
+#  GDCdownload(query, files.per.chunk = 10)
 #  betas <- GDCprepare(query)
 #  
 #  
@@ -305,7 +265,6 @@ rowRanges(data)
 #  query.sc.analysis <- GDCquery(
 #      project = "CPTAC-3",
 #      data.category = "Transcriptome Profiling",
-#      legacy = FALSE,
 #      access = "open",
 #      data.type = "Single Cell Analysis",
 #      data.format =  "TSV"
@@ -317,7 +276,6 @@ rowRanges(data)
 #  query.hdF5 <- GDCquery(
 #      project = "CPTAC-3",
 #      data.category = "Transcriptome Profiling",
-#      legacy = FALSE,
 #      access = "open",
 #      data.type = "Single Cell Analysis",
 #      barcode = c("CPT0167860015","CPT0206880004"),
@@ -330,7 +288,6 @@ rowRanges(data)
 #  query.raw.counts <- GDCquery(
 #      project = "CPTAC-3",
 #      data.category = "Transcriptome Profiling",
-#      legacy = FALSE,
 #      access = "open",
 #      data.type = "Gene Expression Quantification",
 #      barcode = c("CPT0167860015","CPT0206880004"),
@@ -343,7 +300,6 @@ rowRanges(data)
 #  query.filtered.counts <- GDCquery(
 #      project = "CPTAC-3",
 #      data.category = "Transcriptome Profiling",
-#      legacy = FALSE,
 #      access = "open",
 #      data.type = "Gene Expression Quantification",
 #      barcode = c("CPT0167860015","CPT0206880004"),
@@ -356,7 +312,6 @@ rowRanges(data)
 #  query.sc.dea <- GDCquery(
 #      project = "CPTAC-3",
 #      data.category = "Transcriptome Profiling",
-#      legacy = FALSE,
 #      access = "open",
 #      data.type = "Differential Gene Expression",
 #      barcode = c("CPT0167860015","CPT0206880004"),
@@ -365,76 +320,3 @@ rowRanges(data)
 #  GDCdownload(query.sc.dea)
 #  sc.dea.list <- GDCprepare(query.sc.dea)
 
-## ----message=FALSE, warning=FALSE, eval =FALSE--------------------------------
-#  #-------------------------------------------------------
-#  # Example to idat files from TCGA projects
-#  #-------------------------------------------------------
-#  projects <- TCGAbiolinks:::getGDCprojects()$project_id
-#  projects <- projects[grepl('^TCGA',projects,perl=T)]
-#  match.file.cases.all <- NULL
-#  for(proj in projects){
-#      print(proj)
-#      query <- GDCquery(
-#          project = proj,
-#          data.category = "Raw microarray data",
-#          data.type = "Raw intensities",
-#          experimental.strategy = "Methylation array",
-#          legacy = TRUE,
-#          file.type = ".idat",
-#          platform = "Illumina Human Methylation 450"
-#      )
-#      match.file.cases <- getResults(query,cols=c("cases","file_name"))
-#      match.file.cases$project <- proj
-#      match.file.cases.all <- rbind(match.file.cases.all,match.file.cases)
-#      tryCatch(
-#          GDCdownload(query, method = "api", files.per.chunk = 20),
-#          error = function(e) GDCdownload(query, method = "client")
-#      )
-#  }
-#  # This will create a map between idat file name, cases (barcode) and project
-#  readr::write_tsv(match.file.cases.all, path =  "idat_filename_case.txt")
-#  # code to move all files to local folder
-#  for(file in dir(".",pattern = ".idat", recursive = T)){
-#      TCGAbiolinks::move(file,basename(file))
-#  }
-
-## ---- eval = FALSE------------------------------------------------------------
-#  query_meth.hg19 <- GDCquery(
-#      project= "TCGA-LGG",
-#      data.category = "DNA methylation",
-#      platform = "Illumina Human Methylation 450",
-#      barcode = c("TCGA-HT-8111-01A-11D-2399-05","TCGA-HT-A5R5-01A-11D-A28N-05"),
-#      legacy = TRUE
-#  )
-#  GDCdownload(query_meth.hg19)
-#  data.hg19 <- GDCprepare(query_meth.hg19)
-
-## ---- eval = FALSE------------------------------------------------------------
-#  query <- GDCquery(
-#      project = "TCGA-GBM",
-#      data.category = "Protein expression",
-#      legacy = TRUE,
-#      barcode = c("TCGA-OX-A56R-01A-21-A44T-20","TCGA-08-0357-01A-21-1898-20")
-#  )
-#  GDCdownload(query)
-#  data <- GDCprepare(
-#      query, save = TRUE,
-#      save.filename = "gbmProteinExpression.rda",
-#      remove.files.prepared = TRUE
-#  )
-
-## ---- eval = FALSE------------------------------------------------------------
-#  # Aligned against Hg19
-#  query.exp.hg19 <- GDCquery(
-#      project = "TCGA-GBM",
-#      data.category = "Gene expression",
-#      data.type = "Gene expression quantification",
-#      platform = "Illumina HiSeq",
-#      file.type  = "normalized_results",
-#      experimental.strategy = "RNA-Seq",
-#      barcode = c("TCGA-14-0736-02A-01R-2005-01", "TCGA-06-0211-02A-02R-2005-01"),
-#      legacy = TRUE
-#  )
-#  GDCdownload(query.exp.hg19)
-#  data <- GDCprepare(query.exp.hg19)
-
