@@ -10,17 +10,19 @@ library(DT)
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
 subtypes <- PanCancerAtlas_subtypes()
-DT::datatable(subtypes,
-             filter = 'top',
-             options = list(scrollX = TRUE, keys = TRUE, pageLength = 5),
-             rownames = FALSE)
+DT::datatable(
+    data = subtypes,
+    filter = 'top',
+    options = list(scrollX = TRUE, keys = TRUE, pageLength = 5),
+    rownames = FALSE
+)
 
-## ---- eval = FALSE------------------------------------------------------------
-#  lgg.gbm.subtype <- TCGAquery_subtype(tumor = "lgg")
+## ---- eval = TRUE-------------------------------------------------------------
+lgg_gbm_subtype <- TCGAquery_subtype(tumor = "lgg")
 
 ## ---- eval = TRUE, echo = FALSE-----------------------------------------------
 datatable(
-  lgg.gbm.subtype[1:10,],
+  lgg_gbm_subtype[1:10,],
   caption = "Table with LGG molecular subtypes from TCGAquery_subtype",
   filter = 'top',
   options = list(scrollX = TRUE, keys = TRUE, pageLength = 5), 
